Interaction
===========

.. currentmodule:: pykeen.nn.modules

.. autoclass:: Interaction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Interaction.entity_shape
      ~Interaction.relation_shape
      ~Interaction.tail_entity_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~Interaction.forward
      ~Interaction.get_dimensions
      ~Interaction.reset_parameters
      ~Interaction.score
      ~Interaction.score_h
      ~Interaction.score_hrt
      ~Interaction.score_r
      ~Interaction.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape
   .. autoattribute:: tail_entity_shape

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: get_dimensions
   .. automethod:: reset_parameters
   .. automethod:: score
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_r
   .. automethod:: score_t
